@@ -2,8 +2,13 @@ from collections import deque
 
 from pyredis import commands
 from pyredis.connection import Connection
-from pyredis.exceptions import PyRedisError, PyRedisConnError, PyRedisConnReadTimeout, ReplyError
-from pyredis.helper import dict_from_list, ClusterMap, slot_from_key
+from pyredis.exceptions import PyRedisError
+from pyredis.exceptions import PyRedisConnError
+from pyredis.exceptions import PyRedisConnReadTimeout
+from pyredis.exceptions import ReplyError
+from pyredis.helper import dict_from_list
+from pyredis.helper import ClusterMap
+from pyredis.helper import slot_from_key
 
 
 class Client(
@@ -19,7 +24,7 @@ class Client(
     commands.String,
     commands.Transaction,
 ):
-    """ Base Client for Talking to Redis.
+    """Base Client for Talking to Redis.
 
     Inherits the following Command classes:
       - commands.Connection,
@@ -38,6 +43,7 @@ class Client(
     :param kwargs:
         pyredis.Client takes the same arguments as pyredis.connection.Connection.
     """
+
     def __init__(self, **kwargs):
         super().__init__()
         self._conn = Connection(**kwargs)
@@ -66,14 +72,14 @@ class Client(
 
     @property
     def bulk(self):
-        """ True if bulk mode is enabled.
+        """True if bulk mode is enabled.
 
         :return: bool
         """
         return self._bulk
 
     def bulk_start(self, bulk_size=5000, keep_results=True):
-        """ Enable bulk mode
+        """Enable bulk mode
 
         Put the client into bulk mode. Instead of executing a command & waiting for
         the reply, all commands are send to Redis without fetching the result.
@@ -100,7 +106,7 @@ class Client(
             self._bulk_keep = True
 
     def bulk_stop(self):
-        """ Stop bulk mode.
+        """Stop bulk mode.
 
         All outstanding results from previous commands get fetched.
         If bulk_start was called with keep_results=True, return a list with all
@@ -121,7 +127,7 @@ class Client(
         return results
 
     def close(self):
-        """ Close client.
+        """Close client.
 
         :return: None
         """
@@ -129,14 +135,14 @@ class Client(
 
     @property
     def closed(self):
-        """ Check if client is closed.
+        """Check if client is closed.
 
         :return: bool
         """
         return self._conn.closed
 
     def execute(self, *args):
-        """ Execute arbitrary redis command.
+        """Execute arbitrary redis command.
 
         :param args:
         :type args: list, int, float
@@ -159,9 +165,9 @@ class ClusterClient(
     commands.Set,
     commands.SSet,
     commands.String,
-    commands.Transaction
+    commands.Transaction,
 ):
-    """ Base Client for Talking to Redis Cluster.
+    """Base Client for Talking to Redis Cluster.
 
     Inherits the following Commmand classes:
       - commands.Connection,
@@ -207,21 +213,22 @@ class ClusterClient(
         Username used for acl scl authentication. If not set, fall back use legacy auth.
     :type username: str
     """
+
     def __init__(
-            self,
-            seeds=None,
-            database=0,
-            password=None,
-            encoding=None,
-            slave_ok=False,
-            conn_timeout=2,
-            read_timeout=2,
-            cluster_map=None,
-            username=None
+        self,
+        seeds=None,
+        database=0,
+        password=None,
+        encoding=None,
+        slave_ok=False,
+        conn_timeout=2,
+        read_timeout=2,
+        cluster_map=None,
+        username=None,
     ):
         super().__init__()
         if not bool(seeds) != bool(cluster_map):
-            raise PyRedisError('Ether seeds or cluster_map has to be provided')
+            raise PyRedisError("Ether seeds or cluster_map has to be provided")
         self._cluster = True
         self._conns = dict()
         self._conn_timeout = conn_timeout
@@ -249,16 +256,17 @@ class ClusterClient(
             del self._conns[conn]
 
     def _connect(self, sock):
-        host, port = sock.split('_')
+        host, port = sock.split("_")
         client = Connection(
-            host=host, port=int(port),
+            host=host,
+            port=int(port),
             conn_timeout=self._conn_timeout,
             read_timeout=self._read_timeout,
             read_only=self._slave_ok,
             encoding=self._encoding,
             password=self._password,
             database=self._database,
-            username=self._username
+            username=self._username,
         )
         self._conns[sock] = client
 
@@ -278,7 +286,7 @@ class ClusterClient(
         return False
 
     def execute(self, *args, shard_key=None, sock=None, asking=False, retries=3):
-        """ Execute arbitrary redis command.
+        """Execute arbitrary redis command.
 
         :param args:
         :type args: list, int, float
@@ -297,30 +305,36 @@ class ClusterClient(
         :return: result, exception
         """
         if not bool(shard_key) != bool(sock):
-            raise PyRedisError('Ether shard_key or sock has to be provided')
+            raise PyRedisError("Ether shard_key or sock has to be provided")
         if not sock:
             sock = self._get_slot_info(shard_key)
         if sock not in self._conns.keys():
             self._connect(sock)
         try:
             if asking:
-                self._conns[sock].write('ASKING', *args)
+                self._conns[sock].write("ASKING", *args)
             else:
                 self._conns[sock].write(*args)
             return self._conns[sock].read()
         except ReplyError as err:
             errstr = str(err)
-            if retries <= 1 and (errstr.startswith('MOVED') or errstr.startswith('ASK')):
-                raise PyRedisError('Slot moved to often or wrong shard_key, giving up,')
-            if errstr.startswith('MOVED'):
+            if retries <= 1 and (
+                errstr.startswith("MOVED") or errstr.startswith("ASK")
+            ):
+                raise PyRedisError("Slot moved to often or wrong shard_key, giving up,")
+            if errstr.startswith("MOVED"):
                 if not shard_key:
-                    raise ReplyError('Explicitly set socket, but key does not belong to this redis: {0}'.format(sock))
+                    raise ReplyError(
+                        "Explicitly set socket, but key does not belong to this redis: {0}".format(
+                            sock
+                        )
+                    )
                 self._map_id = self._map.update(self._map_id)
                 self._cleanup_conns()
-                return self.execute(*args, shard_key=shard_key, retries=retries-1)
-            elif errstr.startswith('ASK'):
-                sock = errstr.split()[2].replace(':', '_')
-                return self.execute(*args, sock=sock, retries=retries-1, asking=True)
+                return self.execute(*args, shard_key=shard_key, retries=retries - 1)
+            elif errstr.startswith("ASK"):
+                sock = errstr.split()[2].replace(":", "_")
+                return self.execute(*args, sock=sock, retries=retries - 1, asking=True)
             else:
                 raise err
         except (PyRedisConnError, PyRedisConnReadTimeout) as err:
@@ -343,8 +357,8 @@ class HashClient(
     commands.String,
     commands.Transaction,
 ):
-    """ Client for Talking to Static Hashed Redis Cluster.
-    
+    """Client for Talking to Static Hashed Redis Cluster.
+
     The Client will calculate a crc16 hash using the shard_key,
     which is be default the first Key in case the command supports multiple keys.
     If the Key is using the TAG annotation "bla{tag}blarg",
@@ -353,7 +367,7 @@ class HashClient(
     a list with 16384 ('host', port) pairs to the "buckets" parameter.
     If you have less then 16384 ('host', port) pairs, the client will try to
     distribute the key spaces evenly between available pairs.
-    
+
     --- Warning ---
     Since this is static hashing, the order of pairs has to match on each client you use!
     Also changing the number of pairs will change the mapping between buckets and pairs,
@@ -372,17 +386,17 @@ class HashClient(
       - commands.String,
       - commands.Transaction
     """
-    def __init__(
-            self,
-            buckets,
-            database=None,
-            password=None,
-            encoding=None,
-            conn_timeout=2,
-            read_timeout=2,
-            username=None
-    ):
 
+    def __init__(
+        self,
+        buckets,
+        database=None,
+        password=None,
+        encoding=None,
+        conn_timeout=2,
+        read_timeout=2,
+        username=None,
+    ):
         super().__init__()
         self._conns = dict()
         self._conn_names = list()
@@ -402,7 +416,7 @@ class HashClient(
             encoding=encoding,
             conn_timeout=conn_timeout,
             read_timeout=read_timeout,
-            username=username
+            username=username,
         )
         self._init_map()
 
@@ -426,10 +440,19 @@ class HashClient(
         if self._bulk_size_current == self._bulk_size:
             self._bulk_fetch()
 
-    def _init_conns(self, buckets, database, password, encoding, conn_timeout, read_timeout, username):
+    def _init_conns(
+        self,
+        buckets,
+        database,
+        password,
+        encoding,
+        conn_timeout,
+        read_timeout,
+        username,
+    ):
         for bucket in buckets:
             host, port = bucket
-            bucketname = '{0}_{1}'.format(host, port)
+            bucketname = "{0}_{1}".format(host, port)
             self._conn_names.append(bucketname)
             self._conns[bucketname] = Connection(
                 host=host,
@@ -439,7 +462,7 @@ class HashClient(
                 encoding=encoding,
                 conn_timeout=conn_timeout,
                 read_timeout=read_timeout,
-                username=username
+                username=username,
             )
 
     def _init_map(self):
@@ -454,14 +477,14 @@ class HashClient(
 
     @property
     def bulk(self):
-        """ True if bulk mode is enabled.
+        """True if bulk mode is enabled.
 
         :return: bool
         """
         return self._bulk
 
     def bulk_start(self, bulk_size=5000, keep_results=True):
-        """ Enable bulk mode
+        """Enable bulk mode
 
         Put the client into bulk mode. Instead of executing a command & waiting for
         the reply, all commands are send to Redis without fetching the result.
@@ -488,7 +511,7 @@ class HashClient(
             self._bulk_keep = True
 
     def bulk_stop(self):
-        """ Stop bulk mode.
+        """Stop bulk mode.
 
         All outstanding results from previous commands get fetched.
         If bulk_start was called with keep_results=True, return a list with all
@@ -509,7 +532,7 @@ class HashClient(
         return results
 
     def close(self):
-        """ Close client.
+        """Close client.
 
         :return: None
         """
@@ -519,14 +542,14 @@ class HashClient(
 
     @property
     def closed(self):
-        """ Check if client is closed.
+        """Check if client is closed.
 
         :return: bool
         """
         return self._closed
 
     def execute(self, *args, shard_key=None, sock=None):
-        """ Execute arbitrary redis command.
+        """Execute arbitrary redis command.
 
         :param args:
         :type args: list, int, float
@@ -545,7 +568,7 @@ class HashClient(
         :return: result, exception
         """
         if not bool(shard_key) != bool(sock):
-            raise PyRedisError('Ether shard_key or sock has to be provided')
+            raise PyRedisError("Ether shard_key or sock has to be provided")
         if not sock:
             sock = self._map[slot_from_key(shard_key)]
         conn = self._conns[sock]
@@ -560,18 +583,19 @@ class HashClient(
 
 
 class PubSubClient(commands.Subscribe):
-    """ Pub/Sub Client.
+    """Pub/Sub Client.
 
     Subscribe part of the Redis Pub/Sub System.
 
     :param kwargs:
         pyredis.PubSubClient takes the same arguments as pyredis.connection.Connection.
     """
+
     def __init__(self, **kwargs):
         self._conn = Connection(**kwargs)
 
     def close(self):
-        """ Close Client
+        """Close Client
 
         :return: None
         """
@@ -579,7 +603,7 @@ class PubSubClient(commands.Subscribe):
 
     @property
     def closed(self):
-        """ Check if Client is closed.
+        """Check if Client is closed.
 
         :return: bool
         """
@@ -589,7 +613,7 @@ class PubSubClient(commands.Subscribe):
         return self._conn.write(*args)
 
     def get(self):
-        """ Fetch published item from Redis.
+        """Fetch published item from Redis.
 
         :return: list
         """
@@ -597,7 +621,7 @@ class PubSubClient(commands.Subscribe):
 
 
 class SentinelClient(object):
-    """ Redis Sentinel Client.
+    """Redis Sentinel Client.
 
     :param sentinels:
         Accepts a list of sentinels in this form: [('sentinel1', 26379), ('sentinel2', 26379), ('sentinel3', 26379)]
@@ -612,6 +636,7 @@ class SentinelClient(object):
         Username used for acl scl authentication. If not set, fall back use legacy auth.
     :type username: str
     """
+
     def __init__(self, sentinels, password=None, username=None):
         self._conn = None
         self._sentinels = deque(sentinels)
@@ -626,10 +651,10 @@ class SentinelClient(object):
             conn_timeout=0.1,
             sentinel=True,
             password=self._password,
-            username=self._username
+            username=self._username,
         )
         try:
-            self.execute('PING')
+            self.execute("PING")
             return True
         except PyRedisConnError:
             self.close()
@@ -641,10 +666,10 @@ class SentinelClient(object):
                 return True
             else:
                 self._sentinels.rotate(-1)
-        raise PyRedisConnError('Could not connect to any sentinel')
+        raise PyRedisConnError("Could not connect to any sentinel")
 
     def close(self):
-        """ Close Connection.
+        """Close Connection.
 
         :return: None
         """
@@ -654,14 +679,14 @@ class SentinelClient(object):
 
     @property
     def sentinels(self):
-        """ Return configured sentinels.
+        """Return configured sentinels.
 
         :return: deque
         """
         return self._sentinels
 
     def execute(self, *args):
-        """ Execute sentinel command.
+        """Execute sentinel command.
 
         :param args:
         :type args: string, int, float
@@ -674,7 +699,7 @@ class SentinelClient(object):
         return self._conn.read()
 
     def get_master(self, name):
-        """ Get Master Info.
+        """Get Master Info.
 
         Return dictionary with master details.
 
@@ -683,21 +708,21 @@ class SentinelClient(object):
 
         :return: dict
         """
-        return dict_from_list(self.execute('SENTINEL', 'master', name))
+        return dict_from_list(self.execute("SENTINEL", "master", name))
 
     def get_masters(self):
-        """ Get list of masters.
+        """Get list of masters.
 
         :return: list of dicts
         """
-        masters = self.execute('SENTINEL', 'masters')
+        masters = self.execute("SENTINEL", "masters")
         result = []
         for master in masters:
             result.append(dict_from_list(master))
         return result
 
     def get_slaves(self, name):
-        """ Get slaves.
+        """Get slaves.
 
         Return a list of dictionaries, with slave details.
 
@@ -706,14 +731,14 @@ class SentinelClient(object):
 
         :return:
         """
-        slaves = self.execute('SENTINEL', 'slaves', name)
+        slaves = self.execute("SENTINEL", "slaves", name)
         result = []
         for slave in slaves:
             result.append(dict_from_list(slave))
         return result
 
     def next_sentinel(self):
-        """ Switch to the Next Sentinel.
+        """Switch to the Next Sentinel.
 
         :return: None
         """
